@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,6 +52,8 @@ package com.openexchange.calendar.printing;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
+
+import org.apache.commons.lang.StringEscapeUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.calendar.printing.days.CalendarTools;
@@ -72,7 +74,7 @@ import com.openexchange.user.UserService;
  */
 public class CPAppointment {
 
-    private static final Log LOG = LogFactory.getLog(CPAppointment.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CPAppointment.class));
 
     private String title, description, location;
 
@@ -107,15 +109,15 @@ public class CPAppointment {
     }
 
     public String getTitle() {
-        return title;
+        return StringEscapeUtils.escapeHtml( title );
     }
 
     public String getDescription() {
-        return description;
+        return StringEscapeUtils.escapeHtml( description );
     }
 
     public String getLocation() {
-        return location;
+        return StringEscapeUtils.escapeHtml( location );
     }
 
     public Date getStartDate() {
