@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -152,12 +152,12 @@ public class CPTool extends WeekAndDayCalculator {
         newEndCal.set(Calendar.SECOND, 59);
         newEndCal.set(Calendar.MILLISECOND, 999);
 
-        Appointment first = (Appointment) appointment.clone();
+        Appointment first = appointment.clone();
         first.setEndDate(newEndCal.getTime());
         appointments.add(first);
 
         for (int i = 1; i < duration; i++) {
-            Appointment middle = (Appointment) appointment.clone();
+            Appointment middle = appointment.clone();
             newStartCal.add(Calendar.DAY_OF_YEAR, 1);
             newEndCal.add(Calendar.DAY_OF_YEAR, 1);
             middle.setStartDate(newStartCal.getTime());
@@ -165,7 +165,7 @@ public class CPTool extends WeekAndDayCalculator {
             appointments.add(middle);
         }
 
-        Appointment last = (Appointment) appointment.clone();
+        Appointment last = appointment.clone();
         newStartCal.add(Calendar.DAY_OF_YEAR, 1);
         last.setStartDate(newStartCal.getTime());
         appointments.add(last);
