@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,18 +54,18 @@ import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-
 import com.openexchange.i18n.I18nService;
 import com.openexchange.i18n.LocaleTools;
 
 /**
  * Registry for all found {@link I18nService} instances.
+ *
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  */
 public class I18nServices {
 
-    private static final Log LOG = LogFactory.getLog(I18nServices.class);
-
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(I18nServices.class));
+    private static final Locale DEFAULT_LOCALE = Locale.US;
     private static final I18nServices SINGLETON = new I18nServices();
 
     private final Map<Locale, I18nService> services = new ConcurrentHashMap<Locale, I18nService>();
@@ -74,38 +74,45 @@ public class I18nServices {
         super();
     }
 
-    public void addService(I18nService service) {
-        services.put(service.getLocale(), service);
+    public void addService(final I18nService service) {
+        if (null != services.put(service.getLocale(), service)) {
+            LOG.warn("Another i18n translation service found for " + service.getLocale());
+        }
     }
 
-    public void removeService(I18nService service) {
-        services.remove(service.getLocale());
+    public void removeService(final I18nService service) {
+        if (null == services.remove(service.getLocale())) {
+            LOG.warn("Unknown i18n translation service shut down for " + service.getLocale());
+        }
     }
 
     public static I18nServices getInstance() {
         return SINGLETON;
     }
 
-    public I18nService getService(Locale locale) {
-        return services.get(locale);
+    public I18nService getService(final Locale locale) {
+        final Locale loc = null == locale ? DEFAULT_LOCALE : locale;
+        final I18nService retval = services.get(loc);
+        if (null == retval && !"en".equalsIgnoreCase(loc.getLanguage())) {
+            LOG.warn("No i18n service for locale " + loc + ".");
+        }
+        return retval;
     }
 
-    public String translate(Locale locale, String toTranslate) {
-        I18nService service = services.get(locale);
+    public String translate(final Locale locale, final String toTranslate) {
+        final Locale loc = null == locale ? DEFAULT_LOCALE : locale;
+        final I18nService service = services.get(loc);
         if (null == service) {
-            if (!"en".equalsIgnoreCase(locale.getLanguage())) {
-                LOG.warn("No i18n service for locale " + locale + ".");
-            }
             return toTranslate;
         }
         if (!service.hasKey(toTranslate)) {
-            LOG.warn("I18n service for locale " + locale + " has no translation for \"" + toTranslate + "\".");
+            LOG.warn("I18n service for locale " + loc + " has no translation for \"" + toTranslate + "\".");
             return toTranslate;
         }
         return service.getLocalized(toTranslate);
     }
 
-    public String translate(String localeId, String toTranslate) {
+    public String translate(final String localeId, final String toTranslate) {
         return translate(LocaleTools.getLocale(localeId), toTranslate);
     }
 }
