@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,14 +54,13 @@ import java.util.Date;
 import java.util.List;
 import com.openexchange.calendar.printing.CPAppointment;
 import com.openexchange.calendar.printing.CPCalendar;
-import com.openexchange.calendar.printing.CPType;
 
 /**
  * This abstract class is the super class for all partitioning strategies that use weeks. Weeks are special, because a view on a month might
  * need to include weeks that do not belong to that month, in case the first or last week of a month contains days from neighbouring months.
  * To do these checks, this class keeps track of days, weeks and months internally. It works stateful, unlike its super class, which only
  * contains non-stateful classes.
- * 
+ *
  * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias Prinz</a>
  */
 public abstract class AbstractWeekPartitioningStrategy extends WeekAndDayCalculator implements CPPartitioningStrategy {
@@ -184,7 +183,7 @@ public abstract class AbstractWeekPartitioningStrategy extends WeekAndDayCalcula
         CPCalendar cal = getCalendar();
         cal.setTime(day);
         int dayInYear = cal.get(Calendar.DAY_OF_YEAR);
-        
+
         cal.set(Calendar.DAY_OF_WEEK, cal.getFirstDayOfWorkWeek());
         Date firstDayOfWorkWeek = cal.getTime();
         int firstDayOfWorkWeekInMonthInYear = cal.get(Calendar.DAY_OF_YEAR);
