@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -78,7 +78,7 @@ import com.openexchange.groupware.contexts.Context;
  */
 public class Partitioner {
 
-    private static final Log LOG = LogFactory.getLog(Partitioner.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Partitioner.class));
     private final CPParameters params;
     private final CPCalendar cal;
     private final AppointmentSQLInterface appointmentSql;
@@ -157,12 +157,16 @@ public class Partitioner {
             Appointment appointment = appointmentSql.getObjectById(appointmentId.getObjectID(), appointmentId.getParentFolderID());
             if (appointment.isMaster()) {
                 RecurringResultsInterface results = calendarTools.calculateRecurring(appointment, displayStart.getTime(), CalendarTools.getDayEnd(cal, displayEnd).getTime(), 0);
-                for (int i = 0; i < results.size(); i++) {
-                    RecurringResultInterface result = results.getRecurringResult(i);
-                    Appointment occurrence = appointment.clone();
-                    occurrence.setStartDate(new Date(result.getStart()));
-                    occurrence.setEndDate(new Date(result.getEnd()));
-                    addToMap(dayMap, occurrence);
+                if (results == null) {
+                    addToMap(dayMap, appointment);
+                } else {
+                    for (int i = 0; i < results.size(); i++) {
+                        RecurringResultInterface result = results.getRecurringResult(i);
+                        Appointment occurrence = appointment.clone();
+                        occurrence.setStartDate(new Date(result.getStart()));
+                        occurrence.setEndDate(new Date(result.getEnd()));
+                        addToMap(dayMap, occurrence);
+                    }
                 }
             } else {
                 addToMap(dayMap, appointment);
