@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,6 +55,7 @@ import org.osgi.framework.ServiceRegistration;
 import org.osgi.util.tracker.ServiceTracker;
 import com.openexchange.calendar.printing.CPServlet;
 import com.openexchange.calendar.printing.preferences.CalendarPrintingEnabled;
+import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.group.GroupService;
 import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.calendar.CalendarCollectionService;
@@ -62,13 +63,13 @@ import com.openexchange.groupware.settings.PreferencesItemService;
 import com.openexchange.i18n.I18nService;
 import com.openexchange.server.osgiservice.DeferredActivator;
 import com.openexchange.server.osgiservice.RegistryCustomizer;
-import com.openexchange.templating.TemplateService;
-import com.openexchange.tools.servlet.http.HTTPServletRegistration;
+import com.openexchange.templating.base.TemplateService;
+import com.openexchange.tools.service.SessionServletRegistration;
 import com.openexchange.user.UserService;
 
 /**
  * {@link Activator} - The activator for calendar printing.
- * 
+ *
  * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias Prinz</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
@@ -79,7 +80,7 @@ public class Activator extends DeferredActivator {
      */
     public static final String ALIAS = "/ajax/printCalendar";
 
-    private HTTPServletRegistration registration;
+    private SessionServletRegistration registration;
 
     private ServiceRegistration preferenceItemRegistration;
 
@@ -106,6 +107,7 @@ public class Activator extends DeferredActivator {
         trackers.add(new ServiceTracker(context, I18nService.class.getName(), new I18nCustomizer(context)));
         trackers.add(new ServiceTracker(context, UserService.class.getName(), new RegistryCustomizer<UserService>(context, UserService.class, getInstance())));
         trackers.add(new ServiceTracker(context, GroupService.class.getName(), new RegistryCustomizer<GroupService>(context, GroupService.class, getInstance())));
+        trackers.add(new ServiceTracker(context, ConfigViewFactory.class.getName(), new RegistryCustomizer<ConfigViewFactory>(context, ConfigViewFactory.class, getInstance())));
         for (final ServiceTracker tracker : trackers) {
             tracker.open();
         }
@@ -142,12 +144,13 @@ public class Activator extends DeferredActivator {
         CPServlet.setAppointmentSqlFactoryService(appointmentSqlFactory);
         CPServlet.setCalendarTools(collectionService);
 
-        registration = new HTTPServletRegistration(context, ALIAS, new CPServlet());
+        registration = new SessionServletRegistration(context, new CPServlet(), ALIAS);
+        registration.open();
     }
 
     private void unregister() {
         if (registration != null) {
-            registration.unregister();
+            registration.close();
             registration = null;
         }
     }
