@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,12 +55,13 @@ import com.openexchange.groupware.settings.IValueHandler;
 import com.openexchange.groupware.settings.PreferencesItemService;
 import com.openexchange.groupware.settings.ReadOnlyValue;
 import com.openexchange.groupware.settings.Setting;
+import com.openexchange.groupware.settings.SettingException;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.session.Session;
 
 /**
  * {@link CalendarPrintingEnabled} - Preference item service to mark calendar printing as enabled.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class CalendarPrintingEnabled implements PreferencesItemService {
@@ -77,12 +78,12 @@ public class CalendarPrintingEnabled implements PreferencesItemService {
 
     public IValueHandler getSharedValue() {
         return new ReadOnlyValue() {
-            
+
             public boolean isAvailable(UserConfiguration userConfig) {
                 return userConfig.hasCalendar();
             }
-            
-            public void getValue(Session session, Context ctx, User user, UserConfiguration userConfig, Setting setting) {
+
+            public void getValue(Session session, Context ctx, User user, UserConfiguration userConfig, Setting setting) throws SettingException {
                 setting.setSingleValue(Boolean.TRUE);
             }
         };
